from fastapi import FastAPI, Request
from fastapi.middleware.cors import CORSMiddleware
from pydantic import BaseModel
from paddleocr import PaddleOCR

from core.direction import AngleDetector
from core.ocr import IdCardOcr
from utils.image import *
from utils.time import timeit
from utils.web import web_try
import os


app = FastAPI()

origins = ["*"]

app.add_middleware(
    CORSMiddleware,
    allow_origins=origins,
    allow_credentials=True,
    allow_methods=["*"],
    allow_headers=["*"],
)
use_gpu = os.getenv('USE_CUDA') == 'gpu'
print(f'use gpu: {use_gpu}')

ocr = PaddleOCR(
                rec_model_dir='./modules/rec',
                det_model_dir='./modules/det',
                cls_model_dir='./modules/cls',
                ocr_version='PP-OCRv2',
                rec_algorithm='CRNN',
                use_angle_cls=True,
                use_gpu=use_gpu,
                )

# 初始化 角度检测器 对象
ad = AngleDetector(ocr)

m = IdCardOcr(ocr, ad)

@app.get("/ping")
def ping():
    return "pong!"

class ParamInfo(BaseModel):
    image: str
    image_type: str


@app.post("/ocr_system/schoolcert")
@web_try()
@timeit
def detect(request: Request, param: ParamInfo):
    image = base64_to_np(param.image)
    cv2.imwrite('out_put/out.jpg', image)
    return m.predict(image, param.image_type)


if __name__ == '__main__':
    import uvicorn
    import argparse

    parser = argparse.ArgumentParser()
    parser.add_argument('--host', default='0.0.0.0')
    parser.add_argument('--port', default=8080)
    opt = parser.parse_args()


    app_str = 'server:app'  # make the app string equal to whatever the name of this file is
    uvicorn.run(app_str, host=opt.host, port=int(opt.port), reload=True)
